summaryrefslogtreecommitdiff
path: root/mm/rmap.c
diff options
context:
space:
mode:
Diffstat (limited to 'mm/rmap.c')
-rw-r--r--mm/rmap.c19
1 files changed, 11 insertions, 8 deletions
diff --git a/mm/rmap.c b/mm/rmap.c
index f96cc7eb23ec..86ed2865210d 100644
--- a/mm/rmap.c
+++ b/mm/rmap.c
@@ -1698,14 +1698,15 @@ static bool try_to_unmap_one(struct folio *folio, struct vm_area_struct *vma,
break;
}
/*
* Note: We *don't* remember yet if the page was mapped
* exclusively in the swap entry, so swapin code has
* to re-determine that manually and might detect the
* page as possibly shared, for example, if there are
* other references on the page or if the page is under
* writeback. We made sure that there are no GUP pins
* on the page that would rely on it, so for GUP pins
* this is fine.
*/
if (list_empty(&mm->mmlist)) {
spin_lock(&mmlist_lock);
@@ -1716,6 +1717,8 @@ static bool try_to_unmap_one(struct folio *folio, struct vm_area_struct *vma,
dec_mm_counter(mm, MM_ANONPAGES);
inc_mm_counter(mm, MM_SWAPENTS);
swp_pte = swp_entry_to_pte(entry);
+ if (anon_exclusive)
+ swp_pte = pte_swp_mkexclusive(swp_pte);
if (pte_soft_dirty(pteval))
swp_pte = pte_swp_mksoft_dirty(swp_pte);
if (pte_uffd_wp(pteval))
@@ -1698,14 +1698,15 @@ static bool try_to_unmap_one(struct folio *folio, struct vm_area_struct *vma,
}
/*
- * Note: We *don't* remember yet if the page was mapped
- * exclusively in the swap entry, so swapin code has
- * to re-determine that manually and might detect the
- * page as possibly shared, for example, if there are
- * other references on the page or if the page is under
- * writeback. We made sure that there are no GUP pins
- * on the page that would rely on it, so for GUP pins
- * this is fine.
+ * Note: We *don't* remember if the page was mapped
+ * exclusively in the swap pte if the architecture
+ * doesn't support __HAVE_ARCH_PTE_SWP_EXCLUSIVE. In
+ * that case, swapin code has to re-determine that
+ * manually and might detect the page as possibly
+ * shared, for example, if there are other references on
+ * the page or if the page is under writeback. We made
+ * sure that there are no GUP pins on the page that
+ * would rely on it, so for GUP pins this is fine.
*/
if (list_empty(&mm->mmlist)) {